@@ -1,3 +1,27 @@
+"""
+MIT License
+
+Copyright (c) 2020 myerfire
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
+"""
+
 from .. import utils
 from .stats import KillsDeaths, WinsLosses
 
@@ -5,7 +29,7 @@ from .stats import KillsDeaths, WinsLosses
 class Skywars:
     def __init__(self, data):
         self.name = "Skywars"
-        self.prestige = Prestige(data)
+        self.prestige = Prestige(data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("skywars_experience", 0))
         self.games_played = data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("games_played_skywars", 0)
         self.coins = data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("coins", 0)
         self.tokens = data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("cosmetic_tokens", 0)
@@ -25,9 +49,9 @@ class Skywars:
 
 
 class Prestige:
-    def __init__(self, data):
-        self.exact = utils.get_skywars_level_exact(data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("skywars_experience", 0))
-        self.star = utils.get_skywars_level(data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("skywars_experience", 0))
+    def __init__(self, experience):
+        self.exact = utils.get_skywars_level_exact(experience)
+        self.star = utils.get_skywars_level(experience)
         self.next = self.star + 1
         self.star_index = self.star // 5
         self.percentage = utils.get_level_percentage(self.exact)
